﻿'=========================================================================================================
' Module:       PhotoQueue
' Date:         16/10/2011
' Revised:      16/10/2011
' Author:       Tyron Harford (original http://channel9.msdn.com/coding4fun/articles/Photo-Screensaver)
'=========================================================================================================
Imports System
Imports System.Collections.Generic
Imports System.Data.OleDb
Imports System.Diagnostics
Imports System.IO
Imports System.Text
Imports ViperWorks.Media.Collage.Models

Namespace Classes
    '''===================================================================================================
    ''' <summary>
    ''' Provides a photo queue.
    ''' </summary>
    '''===================================================================================================
    Public Class PhotoQueue
        Private _ImageExtensions As String = "*.bmp;*.gif;*.png;*.jpg;*.jpeg"
        Private _LastShownIndex As Integer = -1
        Private _Photos As List(Of PhotoInfo)
        Private _MyRandom As New Random()

#Region " Constructors "
        '''===============================================================================================
        ''' <summary>
        ''' Default static constructor.
        ''' </summary>
        '''===============================================================================================
        Shared Sub New()
        End Sub
        '''===============================================================================================
        ''' <summary>
        ''' Default constructor.
        ''' </summary>
        '''===============================================================================================
        Public Sub New()
            Me.InitFileList()
            Me._LastShownIndex = -1
        End Sub
#End Region

#Region " Properties "
        '''===============================================================================================
        ''' <summary>
        ''' Returns a count of available photos.
        ''' </summary>
        '''===============================================================================================
        Public ReadOnly Property PhotoCount() As Integer
            Get
                Return _Photos.Count
            End Get
        End Property
#End Region

        '''===============================================================================================
        ''' <summary>
        ''' Initializes the photo list.
        ''' </summary>
        '''===============================================================================================
        Private Sub InitFileList()
            ' if we have no photos, just return.
            Me._Photos = New List(Of PhotoInfo)()
            If My.Settings.PhotoPaths Is Nothing Then
                Return
            End If

            ' go through each of the directories we have specified.
            For Each PhotoDirectory As String In My.Settings.PhotoPaths

                ' make sure we have a valid directory.
                If (String.IsNullOrEmpty(PhotoDirectory) = False AndAlso Directory.Exists(PhotoDirectory)) Then
                    Dim searchType As SearchOption = SearchOption.AllDirectories

                    ' go through all the valid extension types.
                    For Each Extension As String In Me._ImageExtensions.Split(New Char() {";"c})
                        Dim strArray() As String = Directory.GetFiles(PhotoDirectory, Extension, searchType)

                        ' add all the found photos for valid extensions.
                        For Each ImageFile As String In strArray
                            Me._Photos.Add(New PhotoInfo(ImageFile))
                        Next ImageFile
                    Next Extension
                End If
            Next PhotoDirectory

            ' we have our photos, shuffle them to prevent same order appearing.
            Me.ShuffleFiles()
        End Sub
        '''===============================================================================================
        ''' <summary>
        ''' Gets the next image to display.
        ''' </summary>
        '''===============================================================================================
        Public Function GetNextImage() As PhotoInfo
            SyncLock Me._Photos
                If Me._Photos.Count = 0 Then
                    Return Nothing
                End If
                If Me._LastShownIndex >= (Me._Photos.Count - 1) Then
                    Me.ShuffleFiles()
                    Me._LastShownIndex = -1
                End If
                Me._LastShownIndex += 1
                Return Me._Photos(Me._LastShownIndex)
            End SyncLock
        End Function
        '''===============================================================================================
        ''' <summary>
        ''' Shuffles the listing of photos.
        ''' </summary>
        '''===============================================================================================
        Private Sub ShuffleFiles()
            SyncLock Me._Photos
                Dim num As Integer = 0
                For i As Integer = 0 To (Me._Photos.Count - 1) - 1
                    Do While num = i
                        num = Me._MyRandom.Next(0, Me._Photos.Count)
                    Loop
                    Dim info As PhotoInfo = Me._Photos(i)
                    Me._Photos(i) = Me._Photos(num)
                    Me._Photos(num) = info
                    num = i + 1
                Next i
            End SyncLock
        End Sub
        '''===============================================================================================
        ''' <summary>
        ''' Converts a URL to a path.
        ''' </summary>
        ''' <param name="url">The URL to convert.</param>
        '''===============================================================================================
        Private Shared Function ConvertUrlToPath(ByVal URL As String) As String
            Dim str As String = URL
            If URL.StartsWith("otfs://") Then
                Dim index As Integer = URL.IndexOf("}/")
                str = URL.Substring(index + 2)
                Dim length As Integer = str.IndexOf("/")
                str = str.Substring(0, length) & ":" & str.Substring(length)
            ElseIf URL.StartsWith("file:") Then
                str = URL.Substring(5)
            End If
            Return str.Replace("/"c, "\"c)
        End Function
    End Class
End Namespace

