﻿'=========================================================================================================
' Module:       ScreenSaverForm
' Date:         16/10/2011
' Revised:      16/10/2011
' Author:       Tyron Harford (original http://channel9.msdn.com/coding4fun/articles/Photo-Screensaver)
'=========================================================================================================
Imports System
Imports System.ComponentModel
Imports System.Diagnostics
Imports System.Drawing
Imports System.Drawing.Imaging
Imports System.Windows.Forms
Imports System.Threading
Imports System.Drawing.Drawing2D
Imports ViperWorks.Media.Collage.Models

Namespace Forms
    '''===================================================================================================
    ''' <summary>
    ''' Core screensaver form.
    ''' </summary>
    '''===================================================================================================
    Partial Public Class ScreenSaverForm
        Inherits Form

#Region " Private Variables "
        Private _DesktopImage As Bitmap
        Private _DesktopPhotoPile As Bitmap
        Private _PhotoSource As Classes.PhotoQueue
        Private _BackroundThread As Thread
        Private _CaptionFormat As New StringFormat()
        Private _DelayInterval As Integer
        Private _ImageBuffer As Integer = 20
        Private _ImageHeight As Integer = 240
        Private _ImageWidth As Integer = 240
        Private _LastResetTime As Long
        Private _ResetInterval As Integer
        Private _MyRandom As New Random()
        Private _ShownTime As Long
        Private _HomeScreen As Screen
        Private _MouseLocation As Point
        Private _RefreshHandler As EventHandler
        Private _QuoteTime As DateTime = DateTime.Now
        Private _InfoText As String
        Private _CurrentItem As Models.DisplayItem
        Private _DrawBrushSidebarDate As Brush
        Private _DrawBrushSidebar As Brush
        Private _Left As Integer
        Private _FontMargin As Integer = 0
#End Region

#Region " Constructor / Init "
        '''===============================================================================================
        ''' <summary>
        ''' Constructor.
        ''' </summary>
        ''' <param name="HomeScreen">The screen we're running the screensaver on.</param>
        ''' <param name="Source">The source of photos.</param>
        '''===============================================================================================
        Public Sub New(ByVal HomeScreen As Screen, ByVal Source As Classes.PhotoQueue)
            Me.InitializeComponent()

            ' set homescreen (screen on computer), the source of photos
            ' and get the background image (current desktop).
            Me._HomeScreen = HomeScreen
            Me._PhotoSource = Source
            Me._DesktopImage = Me.GetBackgroundImage()

            ' if we're running as a screensaver, attach onto key and mouse events.
            If Program.RunningAsScreensaver Then
                AddHandler KeyUp, AddressOf BaseScreenSaverForm_KeyDown
                AddHandler MouseMove, AddressOf BaseScreenSaverForm_MouseEvent
                AddHandler MouseDown, AddressOf BaseScreenSaverForm_MouseEvent
            End If
            AddHandler KeyDown, AddressOf BaseScreenSaverForm_KeyDown

            ' configure main colors.
            Me._DrawBrushSidebar = New SolidBrush(Color.FromArgb(My.Settings.BarOpacity, Color.FromName(My.Settings.SidebarColor)))
            Me._DrawBrushSidebarDate = New SolidBrush(Color.FromName(My.Settings.SidebarDateFontColor))

            ' set the sidebar position to the left or right.
            If (My.Settings.SidebarPosition.ToLower() = "left") Then
                Me._Left = 0
                Me._FontMargin = 20
            Else
                Me._Left = Me._HomeScreen.Bounds.Width - 300
                Me._FontMargin = 0
            End If

            ' setup the event handler and configure the form
            ' for screensaver use (ie. hide cursor, maximize form, etc)
            Me._RefreshHandler = New EventHandler(AddressOf Me.ScreenSaver_CurrentImageUpdated)
            Me.ConfigureForm()
        End Sub
        '''===============================================================================================
        ''' <summary>
        ''' Performs init tasks, image dimensions, intervals and caption format.
        ''' Starts the background thread for drawing.
        ''' </summary>
        '''===============================================================================================
        Public Sub Init()
            Me._ImageHeight = CInt(Fix(Me._DesktopImage.VerticalResolution * 2.5))
            Me._ImageWidth = CInt(Fix(Me._DesktopImage.HorizontalResolution * 2.5))
            Me._ImageBuffer = CInt(Fix(Me._ImageHeight * 0.08))
            Me._CaptionFormat.Alignment = StringAlignment.Center
            Me._CaptionFormat.LineAlignment = StringAlignment.Center
            Me._CaptionFormat.Trimming = StringTrimming.EllipsisCharacter
            Me._DesktopPhotoPile = New Bitmap(Me._DesktopImage)
            Me._ResetInterval = 180 * 1000
            Me._DelayInterval = My.Settings.Interval * 1000
            Me._LastResetTime = Environment.TickCount
            Me._ShownTime = Environment.TickCount
            Me._BackroundThread = New Thread(New ThreadStart(AddressOf Me.ImageUpdater))
            Me._BackroundThread.IsBackground = True
            Me._BackroundThread.Start()
        End Sub
        '''===============================================================================================
        ''' <summary>
        ''' Configures the form for correct display of a screensaver.
        ''' </summary>
        '''===============================================================================================
        Private Sub ConfigureForm()
            MyBase.ControlBox = False
            Me.DoubleBuffered = True
            MyBase.FormBorderStyle = FormBorderStyle.None
            MyBase.ShowInTaskbar = False
            MyBase.TopMost = True
            MyBase.WindowState = FormWindowState.Normal
            MyBase.ShowIcon = False
            MyBase.StartPosition = FormStartPosition.Manual
            MyBase.SetStyle(ControlStyles.OptimizedDoubleBuffer Or ControlStyles.AllPaintingInWmPaint Or ControlStyles.UserPaint, True)
            MyBase.Capture = True
            MyBase.Bounds = Me._HomeScreen.Bounds
            Cursor.Hide()
            If Debugger.IsAttached Then
                MyBase.Opacity = 0.8
                MyBase.TopMost = False
            End If
        End Sub
#End Region

#Region " Exit Events "
        '''===============================================================================================
        ''' <summary>
        ''' If we're running as a screensaver, on any keypress exit.
        ''' If we're running as a desktop app, exit on Escape press.
        ''' </summary>
        '''===============================================================================================
        Private Sub BaseScreenSaverForm_KeyDown(ByVal sender As Object, ByVal e As KeyEventArgs)
            If Program.RunningAsScreensaver OrElse (e.KeyCode = Keys.Escape) Then
                Application.Exit()
            End If
        End Sub
        '''===============================================================================================
        ''' <summary>
        ''' On any mouse event as a screensaver, exit.
        ''' </summary>
        '''===============================================================================================
        Private Sub BaseScreenSaverForm_MouseEvent(ByVal sender As Object, ByVal e As MouseEventArgs)
            If (Not Me._MouseLocation.IsEmpty) Then
                If Me._MouseLocation <> e.Location Then
                    Application.Exit()
                End If
                If e.Clicks > 0 Then
                    Application.Exit()
                End If
            End If
            Me._MouseLocation = e.Location
        End Sub
#End Region

#Region " Background Image "
        '''===============================================================================================
        ''' <summary>
        ''' Gets the background image of the computer (ie. desktop).
        ''' </summary>
        '''===============================================================================================
        Public Function GetBackgroundImage() As Bitmap
            Dim image As Bitmap = Nothing
            Dim graphics As Graphics
            Dim bounds As Rectangle = Me._HomeScreen.Bounds
            image = New Bitmap(bounds.Width, bounds.Height, PixelFormat.Format32bppArgb)
            graphics = graphics.FromImage(image)
            Using graphics
                graphics.CopyFromScreen(bounds.X, bounds.Y, 0, 0, bounds.Size, CopyPixelOperation.SourceCopy)
            End Using
            Return image
        End Function
#End Region

#Region " Image Updating/Drawing "
        '''===============================================================================================
        ''' <summary>
        ''' Gets the current drawn desktop of photos.
        ''' </summary>
        '''===============================================================================================
        Public Function GetCurrentImage() As Bitmap
            Return Me._DesktopPhotoPile
        End Function
        '''===============================================================================================
        ''' <summary>
        ''' Core loop that does the drawing.
        ''' </summary>
        '''===============================================================================================
        Public Sub ImageUpdater()
            Do
                Try
                    Using graphics As Graphics = graphics.FromImage(Me._DesktopPhotoPile)
                        If (Environment.TickCount - Me._LastResetTime) > Me._ResetInterval Then
                            Me._DesktopPhotoPile = New Bitmap(Me._DesktopImage)
                            Me._LastResetTime = Environment.TickCount
                        End If
                        Dim nextImage As PhotoInfo = Me._PhotoSource.GetNextImage()
                        If nextImage IsNot Nothing Then
                            Try
                                If nextImage.WorkingBitmap Is Nothing Then
                                    Me.CreateSnapshotImage(nextImage)
                                End If
                                If nextImage.WorkingBitmap IsNot Nothing Then
                                    Me.DrawImageRotated(nextImage)
                                End If
                            Catch
                            End Try
                        End If
                    End Using
                Catch ex As Exception
                Finally
                    ' refresh the form and sleep until next draw.
                    Me._RefreshHandler(Me, Nothing)
                    Thread.Sleep(Me._DelayInterval)
                End Try
            Loop
        End Sub
        '''===============================================================================================
        ''' <summary>
        ''' Creates the snapshot image of a photo.
        ''' </summary>
        '''===============================================================================================
        Private Sub CreateSnapshotImage(ByVal originalPhoto As PhotoInfo)
            Dim height As Integer = (Me._ImageBuffer + Me._ImageHeight) + Me._ImageBuffer
            Dim width As Integer = (Me._ImageBuffer + Me._ImageWidth) + Me._ImageBuffer
            height += Me._ImageBuffer * 3
            Dim bitmap As New Bitmap(width, height)
            Dim image As Image = PhotoInfo.ConstrainSize(originalPhoto.SourceBitmap, Me._ImageWidth, Me._ImageHeight, True)
            '
            Using graphics As Graphics = graphics.FromImage(bitmap)
                PhotoInfo.SetDrawingQuality(graphics)
                graphics.Clear(Color.FromName(My.Settings.PhotoBackgroundColor))
                graphics.DrawRectangle(New Pen(Brushes.Gray, 3.0F), 0, 0, bitmap.Width - 1, bitmap.Height - 1)
                Select Case Classes.ExifSupport.GetExifShort(originalPhoto.SourceBitmap, &H112, 1)
                    Case 3
                        image.RotateFlip(RotateFlipType.Rotate180FlipNone)

                    Case 6
                        image.RotateFlip(RotateFlipType.Rotate90FlipNone)

                    Case 8
                        image.RotateFlip(RotateFlipType.Rotate270FlipNone)
                End Select
                graphics.DrawImage(image, Me._ImageBuffer, Me._ImageBuffer)
                graphics.DrawRectangle(Pens.LightGray, Me._ImageBuffer, Me._ImageBuffer, Me._ImageWidth - 1, Me._ImageHeight - 1)
                Me.RenderCaption(originalPhoto, width, graphics)
            End Using
            originalPhoto.SourceBitmap = Nothing
            originalPhoto.WorkingBitmap = bitmap
        End Sub
        '''===============================================================================================
        ''' <summary>
        ''' Draws the rotated image.
        ''' </summary>
        '''===============================================================================================
        Private Sub DrawImageRotated(ByVal photo As PhotoInfo)
            Dim x As Integer = Me._MyRandom.Next(Me._DesktopPhotoPile.Width - Me._ImageWidth)
            Dim y As Integer = Me._MyRandom.Next(Me._DesktopPhotoPile.Height - Me._ImageHeight)
            Dim angle As Single = Me._MyRandom.Next(60) - 30
            Using graphics As Graphics = graphics.FromImage(Me._DesktopPhotoPile)
                PhotoInfo.SetDrawingQuality(graphics)
                graphics.RotateTransform(angle)
                Dim compositingMode As CompositingMode = graphics.CompositingMode
                graphics.CompositingMode = compositingMode.SourceOver
                Using brush As New SolidBrush(Color.FromArgb(70, 30, 30, 30))
                    Dim i As Integer = 8
                    graphics.FillRectangle(brush, CInt(Fix(x + i)), CInt(Fix(y + i)), CInt(Fix(photo.WorkingBitmap.Width - 1)), CInt(Fix(photo.WorkingBitmap.Height - 1)))
                End Using
                graphics.CompositingMode = compositingMode
                graphics.DrawImageUnscaled(photo.WorkingBitmap, x, y)
            End Using
        End Sub
#End Region

#Region " Caption "
        '''===============================================================================================
        ''' <summary>
        ''' Renders the photo caption.
        ''' </summary>
        '''===============================================================================================
        Private Sub RenderCaption(ByVal originalPhoto As PhotoInfo, ByVal trueImageWidth As Integer, ByVal g As Graphics)
            If (My.Settings.CaptionFormat.ToLower() <> "none") Then
                Dim captionFont As Font
                '
                Try
                    If (My.Settings.BoldCaptions) Then
                        captionFont = New Font(My.Settings.CaptionFont, CSng(My.Settings.CaptionSize), FontStyle.Bold)
                    Else
                        captionFont = New Font(My.Settings.CaptionFont, CSng(My.Settings.CaptionSize), FontStyle.Regular)
                    End If
                Catch ex As Exception
                    captionFont = New Font("Tahoma", CSng(10), FontStyle.Regular)
                End Try
                '
                Dim layoutRect As New Rectangle(2, Me._ImageHeight + (Me._ImageBuffer * 2), trueImageWidth - 4, CInt(Fix(Me._ImageBuffer * 2.5)))
                Dim path As New GraphicsPath()
                Dim drawBrush As Brush = New SolidBrush(Color.FromName(My.Settings.PhotoCaptionColor))
                '
                path.AddString(originalPhoto.Caption, captionFont.FontFamily, CInt(Fix(captionFont.Style)), CSng(captionFont.Height), layoutRect, Me._CaptionFormat)
                g.FillPath(drawBrush, path)
            End If
        End Sub
#End Region

#Region " Background Painting "
        '''===============================================================================================
        ''' <summary>
        ''' Event that does the refresh of the form on correct thread.
        ''' </summary>
        '''===============================================================================================
        Private Sub ScreenSaver_CurrentImageUpdated(ByVal sender As Object, ByVal e As EventArgs)
            If Me.InvokeRequired Then
                Me.Invoke(Me._RefreshHandler)
            Else
                Me.Refresh()
            End If
        End Sub
        '''===============================================================================================
        ''' <summary>
        ''' This handles the end event of painting the results onto the screen.
        ''' </summary>
        '''===============================================================================================
        Protected Overrides Sub OnPaintBackground(ByVal e As PaintEventArgs)
            Dim currentImage As Bitmap = Me.GetCurrentImage()
            e.Graphics.DrawImage(currentImage, 0, 0, currentImage.Width, currentImage.Height)
            '
            Try
                If (My.Settings.AllBlacksMode) Then
                    Dim y As Integer
                    Dim x As Integer
                    '
                    If (My.Settings.SidebarPosition.ToLower() = "left") Then
                        x = (Me._HomeScreen.Bounds.Width - My.Resources.AllBlacks.Width) - 50
                    Else
                        x = 50
                    End If
                    y = CInt((Me._HomeScreen.Bounds.Height - My.Resources.AllBlacks.Height) / 2)
                    '
                    e.Graphics.FillRectangle(Me._DrawBrushSidebar, 0, 0, Me._HomeScreen.Bounds.Width, Me._HomeScreen.Bounds.Height)
                    e.Graphics.DrawImage(My.Resources.AllBlacks, x, y, My.Resources.AllBlacks.Width, My.Resources.AllBlacks.Height)
                Else
                    ' if we have no photos at all, draw a background.
                    If (Me._PhotoSource.PhotoCount = 0) Then
                        e.Graphics.FillRectangle(Me._DrawBrushSidebar, 0, 0, Me._HomeScreen.Bounds.Width, Me._HomeScreen.Bounds.Height)
                    End If

                    ' dim the background if user wants.
                    ' don't do it twice though (if we have no photos).
                    If (My.Settings.DimScreen AndAlso Me._PhotoSource.PhotoCount > 0) Then
                        e.Graphics.FillRectangle(Me._DrawBrushSidebar, 0, 0, Me._HomeScreen.Bounds.Width, Me._HomeScreen.Bounds.Height)
                    End If
                End If
                '
                Select Case My.Settings.BarDrawFormat.ToLower()
                    Case "none"
                        ' don't do anything
                        Exit Select
                    Case "all"
                        ' draw on all monitors.
                        Me.DrawSidebar(e)
                        Exit Select
                    Case "nonprimary (s)"
                        If Me._HomeScreen.Primary = False Then
                            Me.DrawSidebar(e)
                        End If
                        Exit Select
                    Case "primary"
                        If Me._HomeScreen.Primary Then
                            Me.DrawSidebar(e)
                        End If
                        Exit Select
                    Case Else
                        Me.DrawSidebar(e)
                        Exit Select
                End Select

            Catch ex As Exception
            End Try
        End Sub
#End Region

#Region " Sidebar Drawing "
        '''===============================================================================================
        ''' <summary>
        ''' Draws the sidebar information.
        ''' </summary>
        '''===============================================================================================
        Private Sub DrawSidebar(ByVal e As PaintEventArgs)
            Dim topPosition As Integer = Me._HomeScreen.Bounds.Height - 200

            ' draw the side bar.
            e.Graphics.FillRectangle(Me._DrawBrushSidebar, Me._Left - 20, 0, Me._Left + 320, Me._HomeScreen.Bounds.Height)

            ' draw the date and time.
            If (My.Settings.ShowClock) Then
                Dim dateFontSmall As Font = Me.Font
                Dim dateFontBig As Font = Me.Font
                '
                Try
                    dateFontSmall = New Font(My.Settings.SidebarDateFont, CInt(My.Settings.SidebarDateSize / 2), FontStyle.Regular)
                Catch ex As Exception
                    dateFontSmall = New Font("Tahoma", 30, FontStyle.Regular)
                End Try
                Try
                    dateFontBig = New Font(My.Settings.SidebarDateFont, My.Settings.SidebarDateSize, FontStyle.Regular)
                Catch ex As Exception
                    dateFontBig = New Font("Tahoma", 60, FontStyle.Regular)
                End Try
                '
                Dim day As String = GetDayName()
                Dim dayNumber As String = GetDayNumber()
                Dim month As String = GetMonth()
                Dim buffer As String = String.Format("{0} {1}", month, dayNumber)
                Dim time As String = GetTime()
                '
                If (My.Settings.Lowercase) Then
                    day = day.ToLower()
                    buffer = buffer.ToLower()
                    time = time.ToLower()
                End If

                ' draw the date/time.
                e.Graphics.TextRenderingHint = System.Drawing.Text.TextRenderingHint.AntiAlias
                e.Graphics.DrawString(day, dateFontSmall, Me._DrawBrushSidebarDate, Me._Left + Me._FontMargin, topPosition)
                e.Graphics.DrawString(buffer, dateFontSmall, Me._DrawBrushSidebarDate, Me._Left + Me._FontMargin, topPosition + 50)
                e.Graphics.DrawString(time, dateFontBig, Me._DrawBrushSidebarDate, (Me._Left + Me._FontMargin) - 6, topPosition + 90)
            End If

            ' draw quote text if required.
            If (My.Settings.QuoteFormat.ToLower() <> "none") Then
                DrawInformation(e)
            End If
        End Sub
        '''===============================================================================================
        ''' <summary>
        ''' Draws the information on the sidebar.
        ''' </summary>
        '''===============================================================================================
        Private Sub DrawInformation(ByVal e As PaintEventArgs)
            ' if we have reached the interval, pick a new info text.
            If (DateTime.Now.Subtract(Me._QuoteTime).Seconds >= My.Settings.InfoInterval) Then
                PickNewInformation()
            End If

            ' if we have no item at all, get a new one.
            If (Me._CurrentItem Is Nothing) Then
                PickNewInformation()
            End If

            ' only draw if we have an item.
            If (Me._CurrentItem IsNot Nothing) Then
                _InfoText = Me._CurrentItem.TopText
                _InfoText &= Environment.NewLine & Environment.NewLine
                _InfoText &= Me._CurrentItem.BottomText
                '
                If My.Settings.Lowercase Then
                    _InfoText = _InfoText.ToLower()
                End If
                '
                Dim drawFont As Font = Me.Font
                Dim drawBrush As Brush = New SolidBrush(Color.FromName(My.Settings.SidebarInfoFontColor))
                Dim topPosition As Integer = 100
                Dim textFormat As New StringFormat()
                '
                textFormat.Alignment = StringAlignment.Near
                textFormat.LineAlignment = StringAlignment.Near
                textFormat.Trimming = StringTrimming.EllipsisCharacter
                '
                Try
                    drawFont = New Font(My.Settings.SidebarFont, My.Settings.SidebarSize, FontStyle.Regular)
                Catch ex As Exception
                    drawFont = New Font("Tahoma", 9, FontStyle.Regular)
                End Try
                '
                Dim layoutRect As New Rectangle(Me._Left + Me._FontMargin, topPosition, 280, Me._HomeScreen.Bounds.Height - 320)
                Dim path As New GraphicsPath()
                e.Graphics.SmoothingMode = SmoothingMode.AntiAlias
                path.AddString(_InfoText, drawFont.FontFamily, CInt(Fix(drawFont.Style)), CSng(drawFont.Height), layoutRect, textFormat)
                e.Graphics.FillPath(Brushes.White, path)
            Else
                PickNewInformation()
            End If
        End Sub
#End Region

#Region " Pick New Information "
        '''===============================================================================================
        ''' <summary>
        ''' Picks a new bit of information to display.
        ''' Note that custom quotes is considered part of Program.RandomQuote. That property will select
        ''' either built in quotes or custom quotes. If you have custom quotes disabled, they are not read
        ''' in when the app starts up.
        ''' </summary>
        '''===============================================================================================
        Private Sub PickNewInformation()
            Dim pos As Integer = 0
            Me._QuoteTime = DateTime.Now
            '
            Select Case My.Settings.AdditionalQuotes.ToLower()
                Case "none"
                    ' only pick a random quote.
                    Me._CurrentItem = Program.RandomQuote

                Case "all"
                    ' pick all.
                    ' if we are only displaying events or words, don't pick quotes.
                    If My.Settings.QuoteFormat.ToLower() = "events or words only" Then
                        pos = _MyRandom.Next(0, 2)
                    Else
                        pos = _MyRandom.Next(0, 3)
                    End If
                    Select Case pos
                        Case 0
                            Me._CurrentItem = Program.RandomEvent
                        Case 1
                            Me._CurrentItem = Program.RandomWord
                        Case 2
                            Me._CurrentItem = Program.RandomQuote
                    End Select

                Case "word definitions"
                    ' pick between a quote and word.
                    ' if we are only displaying events or words, don't pick quotes.
                    If My.Settings.QuoteFormat.ToLower() = "events or words only" Then
                        Me._CurrentItem = Program.RandomWord
                    Else
                        pos = _MyRandom.Next(0, 2)
                        Select Case pos
                            Case 0
                                Me._CurrentItem = Program.RandomWord
                            Case 1
                                Me._CurrentItem = Program.RandomQuote
                        End Select
                    End If

                Case "world events"
                    ' pick between a quote and word.
                    ' if we are only displaying events or words, don't pick quotes.
                    If My.Settings.QuoteFormat.ToLower() = "events or words only" Then
                        Me._CurrentItem = Program.RandomEvent
                    Else
                        pos = _MyRandom.Next(0, 2)
                        Select Case pos
                            Case 0
                                Me._CurrentItem = Program.RandomEvent
                            Case 1
                                Me._CurrentItem = Program.RandomQuote
                        End Select
                    End If
                Case Else
                    Me._CurrentItem = Program.RandomQuote
            End Select
        End Sub
#End Region

#Region " Date/Time Retrieval "
        '''===============================================================================================
        ''' <summary>
        ''' Gets the current time in hours and minutes.
        ''' </summary>
        '''===============================================================================================
        Private Function GetTime() As String
            Dim time As String
            If DateTime.Now.Minute < 10 Then
                time = String.Format("{0}:0{1}", DateTime.Now.Hour, DateTime.Now.Minute)
            Else
                time = String.Format("{0}:{1}", DateTime.Now.Hour, DateTime.Now.Minute)
            End If
            Return time
        End Function
        '''===============================================================================================
        ''' <summary>
        ''' Gets the current day as a name.
        ''' </summary>
        '''===============================================================================================
        Private Function GetDayName() As String
            Return DateTime.Now.DayOfWeek.ToString()
        End Function
        '''===============================================================================================
        ''' <summary>
        ''' Gets the day number.
        ''' </summary>
        '''===============================================================================================
        Private Function GetDayNumber() As String
            Dim dayOfMonth As String
            If DateTime.Now.Day < 10 Then
                dayOfMonth = String.Format("0{0}", DateTime.Now.Day)
            Else
                dayOfMonth = DateTime.Now.Day.ToString()
            End If
            Return dayOfMonth
        End Function
        '''===============================================================================================
        ''' <summary>
        ''' Gets the current month as a name.
        ''' </summary>
        '''===============================================================================================
        Private Function GetMonth() As String
            Dim myMonth As String = ""
            Select Case DateTime.Now.Month
                Case 1
                    myMonth = "January"
                Case 2
                    myMonth = "Febuary"
                Case 3
                    myMonth = "March"
                Case 4
                    myMonth = "April"
                Case 5
                    myMonth = "May"
                Case 6
                    myMonth = "June"
                Case 7
                    myMonth = "July"
                Case 8
                    myMonth = "August"
                Case 9
                    myMonth = "September"
                Case 10
                    myMonth = "October"
                Case 11
                    myMonth = "November"
                Case 12
                    myMonth = "December"
            End Select
            '
            Return myMonth
        End Function
#End Region

    End Class
End Namespace

